@@ -1,28 +1,30 @@
+#
+# pip install pyside6
+#
+from PySide6 import QtWidgets, QtGui
 import logging
 
 logger = logging.getLogger(__name__)
 logging.basicConfig(format='%(levelname)s:%(name)s:%(message)s',
                     level=logging.DEBUG)
 
-# pip install pyside6
-from PySide6.QtWidgets import QMainWindow, QApplication
-from OpenGL.GL import *
 
-
-class Window(QMainWindow):
+class Window(QtWidgets.QMainWindow):
     def __init__(self, parent=None):
         super().__init__(parent)
         # setup opengl widget
-        import glglue.gl3
-        self.controller = glglue.gl3.SampleController()
+        import glglue.gl3.samplecontroller
+        self.controller = glglue.gl3.samplecontroller.SampleController()
         import glglue.pyside6
-        self.glwidget = glglue.pyside6.Widget(self, self.controller)
+        import glglue.utils
+        self.glwidget = glglue.pyside6.Widget(
+            self, self.controller, glglue.utils.get_desktop_scaling_factor())
         self.setCentralWidget(self.glwidget)
 
 
 if __name__ == "__main__":
     import sys
-    app = QApplication(sys.argv)
+    app = QtWidgets.QApplication(sys.argv)
     window = Window()
     window.show()
-    sys.exit(app.exec_())
+    sys.exit(app.exec())
