@@ -1,23 +1,28 @@
 from logging import getLogger
-from OpenGL.GL import (glClear, glFlush, glEnable, glClearColor, glViewport,
-                       GL_COLOR_BUFFER_BIT, GL_DEPTH_BUFFER_BIT, GL_DEPTH_TEST)
-import glglue
-from .cube import Cube
-from .axis import Axis
-
+from typing import Any, List
+from OpenGL import GL
+from . import gizmo
+import glglue.basecontroller
+from glglue import ctypesmath
+import glglue.gl3.vbo
+import glglue.scene.material
+from ..scene import cube
+from . renderer import Renderer
 logger = getLogger(__name__)
 
 
 class SampleController(glglue.basecontroller.BaseController):
     def __init__(self):
         self.clear_color = (0.6, 0.6, 0.4, 0.0)
-        self.axis = Axis(1.0)
-        self.cube = Cube(0.3)
-        self.camera = glglue.ctypesmath.Camera()
+        self.env: List[Any] = []
+        self.drawables: List[Any] = [cube.create_cube(0.3)]
+        self.camera = ctypesmath.Camera()
         self.isInitialized = False
+        self.renderer = Renderer()
+        self.gizmo = gizmo.Gizmo()
 
     def onResize(self, w: int, h: int) -> bool:
-        glViewport(0, 0, w, h)
+        GL.glViewport(0, 0, w, h)
         return self.camera.onResize(w, h)
 
     def onLeftDown(self, x: int, y: int) -> bool:
@@ -59,20 +64,36 @@ class SampleController(glglue.basecontroller.BaseController):
         '''
         milliseconds
         '''
-        self.cube.update(d)
+        for drawable in self.drawables:
+            drawable.update(d)
         return False
 
     def initialize(self):
-        glEnable(GL_DEPTH_TEST)
+        import glglue
+        logger.info(glglue.get_info())
+        GL.glEnable(GL.GL_DEPTH_TEST)
         self.isInitialized = True
 
     def draw(self):
         if not self.isInitialized:
             self.initialize()
-        glClearColor(*self.clear_color)
-        glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
+        GL.glClearColor(*self.clear_color)
+        GL.glClear(GL.GL_COLOR_BUFFER_BIT |
+                   GL.GL_DEPTH_BUFFER_BIT)  # type: ignore
 
-        self.axis.draw(self.camera.projection.matrix, self.camera.view.matrix)
-        self.cube.draw(self.camera.projection.matrix, self.camera.view.matrix)
+        self.gizmo.begin(self.camera)
 
-        glFlush()
+        for e in self.env:
+            self.renderer.draw(
+                e, self.camera.projection.matrix, self.camera.view.matrix)
+        for i, drawable in enumerate(self.drawables):
+            self.renderer.draw(drawable, self.camera.projection.matrix,
+                               self.camera.view.matrix)
+            # aabb
+            aabb = ctypesmath.AABB.new_empty()
+            self.gizmo.aabb(drawable.expand_aabb(aabb))
+
+        self.gizmo.axis(10)
+        self.gizmo.end()
+
+        GL.glFlush()
